@@ -25,18 +25,18 @@ void MailDir20PercentAsRead::runTest()
 {
     timer.start();
     qDebug() << "  Marking 20% of messages as read.";
-    CollectionFetchJob *clj2 = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
+    auto clj2 = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
     clj2->fetchScope().setResource(currentInstance.identifier());
     clj2->exec();
     const Collection::List list2 = clj2->collections();
     for (const Collection &collection : list2) {
-        auto *ifj = new ItemFetchJob(collection, this);
+        auto ifj = new ItemFetchJob(collection, this);
         ifj->exec();
         Item::List itemlist = ifj->items();
         for (int i = ifj->items().count() - 1; i >= 0; i -= 5) {
             Item item = itemlist[i];
             item.setFlag("\\SEEN");
-            auto *isj = new ItemModifyJob(item, this);
+            auto isj = new ItemModifyJob(item, this);
             isj->exec();
         }
     }
